BoxStyle

Struct BoxStyle 

pub struct BoxStyle {
Show 33 fields pub top_left: char, pub top: char, pub top_divider: char, pub top_right: char, pub head_left: char, pub head_horizontal: char, pub head_vertical: char, pub head_right: char, pub head_row_left: char, pub head_row_horizontal: char, pub head_row_cross: char, pub head_row_right: char, pub mid_left: char, pub mid_horizontal: char, pub mid_vertical: char, pub mid_right: char, pub row_left: char, pub row_horizontal: char, pub row_cross: char, pub row_right: char, pub foot_row_left: char, pub foot_row_horizontal: char, pub foot_row_cross: char, pub foot_row_right: char, pub foot_left: char, pub foot_horizontal: char, pub foot_vertical: char, pub foot_right: char, pub bottom_left: char, pub bottom: char, pub bottom_divider: char, pub bottom_right: char, pub ascii: bool,
}
A set of box-drawing characters defining the look of borders.

Layout of the 8-line string that defines a box:

┌─┬┐ top
│ ││ head
├─┼┤ head_row
│ ││ mid
├─┼┤ row
├─┼┤ foot_row
│ ││ foot
└─┴┘ bottom

Fields

top_left: chartop: chartop_divider: chartop_right: charhead_left: charhead_horizontal: charhead_vertical: charhead_right: charhead_row_left: charhead_row_horizontal: charhead_row_cross: charhead_row_right: charmid_left: charmid_horizontal: charmid_vertical: charmid_right: charrow_left: charrow_horizontal: charrow_cross: charrow_right: charfoot_row_left: charfoot_row_horizontal: charfoot_row_cross: charfoot_row_right: charfoot_left: charfoot_horizontal: charfoot_vertical: charfoot_right: charbottom_left: charbottom: charbottom_divider: charbottom_right: charascii: bool

True if this box uses only ASCII characters.

Implementations

Source

impl BoxStyle

pub fn has_visible_edges(&self) -> bool

Returns true if this box has visible outer edges (non-space corners). Edge-less styles like SIMPLE, MINIMAL, and MARKDOWN return false because their corner characters are all spaces — they are designed to be used in tables where internal separators provide structure.

pub fn from_str(box_str: &str, ascii: bool) -> Self

Parse a box style from an 8-line string.

pub fn to_string(&self) -> String

Get the plain text representation of the box definition.