Lines

Struct Lines 

pub struct Lines { /* private fields */ }
A collection of lines (each line is a Renderable).

Each item in Lines is rendered as a single line of output. The highlight option applies a style to a specific 0-indexed line.

Example

use rusty_rich::Lines;

let mut lines = Lines::new();
lines.add("First line");
lines.add("Second line");

Implementations

Source

impl Lines

pub fn new() -> Self

Create a new empty Lines container.

pub fn add( &mut self, renderable: impl Renderable + Send + Sync + 'static, ) -> &mut Self

Add a renderable line to the container.

pub fn highlight(self, index: usize) -> Self

Builder: highlight the line at the given 0-based index.

pub fn style(self, style: Style) -> Self

Builder: set the default style for all lines.