Module layout

Module layout 

Recursive split-pane layout engine with ratio sizing and named regions. Layout — split-pane layout system. Equivalent to Rich’s layout.py.

Structs

Layout
The Layout compute engine. Assigns screen regions to a tree of layout nodes by recursively splitting available space.
Region
A region on screen.

Enums

Direction
Direction of a split.
LayoutNode
A layout node — can be a leaf (containing a renderable) or a split.