pub struct ProgressFile { /* private fields */ }Expand description
A file wrapper that tracks read progress for use with a Progress instance.
Implementations
Sourceimpl ProgressFile
impl ProgressFile
Sourcepub fn bytes_read(&self) -> u64
pub fn bytes_read(&self) -> u64
Get the number of bytes read so far.
Sourcepub fn sync(&self, progress: &mut Progress)
pub fn sync(&self, progress: &mut Progress)
Sync the current read progress to a Progress instance.
Sourcepub fn into_inner(self) -> File
pub fn into_inner(self) -> File
Consume this ProgressFile and return the inner file.