Module screen

Module screen 

Full-screen rendering, alternate screen buffer, and screen update helpers. Screen — full-screen renderable and alternate screen buffer.

Provides the Screen renderable that fills the terminal, cropping or padding content to exactly fit the screen dimensions. Also provides ScreenContext for managing the alternate screen buffer and ScreenUpdate for partial screen updates.

Equivalent to Rich’s screen.py.

Structs

Screen
A renderable that fills the entire terminal screen, cropping or padding its content to exactly fit the screen dimensions.
ScreenContext
A context that enters the alternate screen buffer, provides an update method to display content, and automatically exits the alternate screen buffer on drop.
ScreenUpdate
Represents an update to a screen display.