Module styled

Module styled 

Pre-styled renderable wrapper — applies a style to all output of a renderable. A pre-styled renderable wrapper.

Equivalent to Python Rich’s styled.py. Wraps any renderable and applies a fixed Style to all of its output, combining with any existing styles on the inner segments via Style::combine.

Structs

Styled
Wraps a renderable with a pre-applied style.