Module text

Module text 

Styled text with Span-based markup and text manipulation utilities. Text with spans — equivalent to Rich’s text.py.

Text is a styled string: plain text plus a collection of Spans that mark regions with specific styles.

Structs

Span
A marked-up region in some text.
Text
A renderable piece of text with optional style spans.

Enums

TextType
Represents something that can be used as text: a plain &str or a Text.

Type Aliases

JustifyMethod
OverflowMethod