Tree

Struct Tree 

pub struct Tree {
    pub label: String,
    pub style: Style,
    pub guide_style: Style,
    pub expanded: bool,
    pub highlight: bool,
    pub hide_root: bool,
    pub children: Vec<Tree>,
}
A renderable for a tree structure.

Fields

label: String

The label for this node.

style: Style

Style for this node’s label.

guide_style: Style

Style for the guide lines.

expanded: bool

If true, children are visible.

highlight: bool

If true, highlight string labels.

hide_root: bool

If true, don’t show the root node.

children: Vec<Tree>

Children of this node.

Implementations

Source

impl Tree

pub fn new(label: impl Into<String>) -> Self

Create a new tree node with the given label.

pub fn add(&mut self, label: impl Into<String>) -> &mut Tree

Add a child node, returning a mutable reference to it.

pub fn style(self, style: Style) -> Self

Set the style for this node.

pub fn guide_style(self, style: Style) -> Self

Set the guide style.

pub fn hide_root(self) -> Self

Hide the root node.