pub fn split_text(text: &str, cell_offset: usize) -> (String, String)Expand description
Split text at the given cell offset, returning (left, right).
If the offset falls in the middle of a double-width character, that
character is replaced with spaces in the left part and starts the right.