Progress bars and task tracking. Equivalent to Rich’s progress.py
and progress_bar.py.
Structs
- Progress
- A multi-task progress display.
- Progress
Bar - A single progress bar.
- Progress
File - A file wrapper that tracks read progress for use with a Progress instance.
- Task
- A tracked task within a Progress display.
- Track
Iterator - An iterator wrapper that updates progress as items are consumed.
Equivalent to Python Rich’s
track().