ProgressFile

Struct ProgressFile 

pub struct ProgressFile { /* private fields */ }
A file wrapper that tracks read progress for use with a Progress instance.

Implementations

Source

impl ProgressFile

pub fn new(file: File, task_id: usize, total: u64) -> Self

Create a new ProgressFile.

pub fn bytes_read(&self) -> u64

Get the number of bytes read so far.

pub fn total(&self) -> u64

Get the total file size.

pub fn task_id(&self) -> usize

Get the task ID this ProgressFile is associated with.

pub fn sync(&self, progress: &mut Progress)

Sync the current read progress to a Progress instance.

pub fn inner(&self) -> &File

Get a reference to the inner file.

pub fn inner_mut(&mut self) -> &mut File

Get a mutable reference to the inner file.

pub fn into_inner(self) -> File

Consume this ProgressFile and return the inner file.