pub struct BarColumn {
pub bar: ProgressBar,
pub width: Option<usize>,
}Expand description
Renders the progress bar itself.
Fields
bar: ProgressBarThe underlying progress bar template.
width: Option<usize>Width override (None = auto from available space).
Implementations
Sourceimpl BarColumn
impl BarColumn
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new BarColumn with a default ProgressBar.
Sourcepub fn complete_style(self, s: Style) -> Self
pub fn complete_style(self, s: Style) -> Self
Builder: set the style for the completed portion of the bar.
Sourcepub fn finished_style(self, s: Style) -> Self
pub fn finished_style(self, s: Style) -> Self
Builder: set the style for the remaining portion of the bar.