pub struct Screen {
pub renderable: DynRenderable,
pub style: Option<Style>,
pub application_mode: bool,
}Expand description
A renderable that fills the entire terminal screen, cropping or padding its content to exactly fit the screen dimensions.
Equivalent to Rich’s Screen class.
Fields
renderable: DynRenderableThe child renderable.
style: Option<Style>Optional style applied as a background / padding style.
application_mode: boolIf true, use \n\r line endings (application mode for raw terminals).
Implementations
Sourceimpl Screen
impl Screen
Sourcepub fn new(renderable: impl Renderable + Send + Sync + 'static) -> Self
pub fn new(renderable: impl Renderable + Send + Sync + 'static) -> Self
Create a new Screen wrapping the given renderable.
Sourcepub fn application_mode(self, mode: bool) -> Self
pub fn application_mode(self, mode: bool) -> Self
Builder: set application mode (uses \n\r instead of \n).
Sourcepub fn update<T>(&mut self, update: T)where
T: Into<ScreenUpdate>,
pub fn update<T>(&mut self, update: T)where
T: Into<ScreenUpdate>,
Update the content renderable.