pub struct ScreenContext { /* private fields */ }Expand description
A context that enters the alternate screen buffer, provides an update
method to display content, and automatically exits the alternate screen
buffer on drop.
Created via Console::screen().
Example
ⓘ
let mut console = Console::new();
let ctx = console.screen();
ctx.update("Hello from alt-screen!");
std::thread::sleep(std::time::Duration::from_secs(2));
// ctx drops → exits alt screenImplementations
Sourceimpl ScreenContext
impl ScreenContext