Module theme

Module theme 

Named style maps (170+ defaults) with stack-based inheritance. Theme system — equivalent to Rich’s theme.py.

A Theme maps style names (like “repr.number”, “repr.str”) to Style values, allowing customizable color schemes for different renderable types.

Modules

names
Built-in theme style names used by various Rich renderables.

Structs

Theme
A set of named styles that can be applied to themed output.
ThemeStack
A stack of themes — when looking up a style, themes are checked from top to bottom until a match is found.

Functions

default_theme
Create the default Rich-like theme.